Reference Files
===============

The ``refpix`` step uses a REFPIX reference file, but only when
processing NIRSpec exposures that have been acquired using an IRS2
readout pattern. No other instruments or exposure modes require a
reference file for this step.

.. include:: ../references_general/refpix_reffile.inc
